CollectionNode<T> class final

A finalized tree for an Iterable or Map.

Inheritance

Constructors

CollectionNode(ListQueue<T> node, NodeStyle nodeStyle, {required NodeType nodeType, required bool forcedInline, required bool isMultiline, String? anchor, String? localTag, Iterable<String>? comments, CommentStyle? commentStyle})

Properties

alias String?
Alias name that references other nodes.
no setterinherited
anchor String?
Anchor name that allow other nodes to reference this node.
finalinherited
comments Iterable<String>
Any comments associated with the node.
finalinherited
commentStyle CommentStyle
Node's comment style
finalinherited
forcedInline bool
final
hashCode int
The hash code for this object.
no setterinherited
inheritParentIndent bool
Whether this prefers using its parent's indent while being dumped rather than the indented calculated for parent's children.
no setterinherited
isMultiline bool
Whether this spans multiple lines.
final
localTag String?
A ResolvedTag reverted back to its TagShorthand form.
finalinherited
node ListQueue<T>
Actual node representing the tree.
final
nodeStyle → NodeStyle
Style used to serialize the node within the YAML source string.
finalinherited
nodeType NodeType
Type of node.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tag → ResolvedTag?
Tag directive describing how the node is represented natively.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited