ContentNode class final

A finalized scalar's lines representing the string content of the node to be dumped.

Inheritance

Constructors

ContentNode(Iterable<String> node, NodeStyle nodeStyle, {required bool inheritParentIndent, required bool isMultiline, Iterable<String>? comments, String? anchor, String? localTag, CommentStyle? commentStyle})

Properties

alias String?
Alias name that references other nodes.
no setterinherited
anchor String?
Anchor name that allow other nodes to reference this node.
finalinherited
comments Iterable<String>
Any comments associated with the node.
finalinherited
commentStyle CommentStyle
Node's comment style
finalinherited
hashCode int
The hash code for this object.
no setterinherited
inheritParentIndent bool
Whether this prefers using its parent's indent while being dumped rather than the indented calculated for parent's children.
final
isMultiline bool
Whether this spans multiple lines.
final
localTag String?
A ResolvedTag reverted back to its TagShorthand form.
finalinherited
node Iterable<String>
Actual node representing the tree.
final
nodeStyle → NodeStyle
Style used to serialize the node within the YAML source string.
finalinherited
nodeType NodeType
Type of node.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tag → ResolvedTag?
Tag directive describing how the node is represented natively.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited