BlockDumper class final Dump Scalar Dump List Dump Map Dumpable Views Representation Tree
Dumps a YAML string line-by-line.
Constructors
- BlockDumper(YamlBuffer buffer)
Properties
- buffer → YamlBuffer
-
Represents the reusable buffer used for writing the entire document.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- inlineDumper → InlinedFlowDumper
-
Helper dumper that quickly inlines flow collection that were forced
inline.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dump(
TreeNode< Object> node) → void -
Dumps a
node. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reset(
) → void - Resets the dumper's internal state.
-
toString(
) → String -
A string representation of this object.
inherited
-
visitAliasNode(
ReferenceNode node) → void - Visits a ReferenceNode.
-
visitContentNode(
ContentNode node) → void - Visits a decomposed ContentNode.
-
visitList(
ListNode node) → void - Visits a ListNode.
-
visitMap(
MapNode node) → void - Visits a MapNode.
-
visitTreeNode(
TreeNode< Object> node) → void -
Visits a tree
nodeand redirects it to the appropriate visitor function.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited